==> beast-0.5.5-rc3.tar.gz: beast-0.5.5-rc3/bse/bsemidinotifier.gen-proc.c <==

/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bsemidinotifier.proc"

#include <bse/bseplugin.h>
#include <bse/bseprocedure.h>
#include <bse/bsemidinotifier.h>
#include <sys/time.h>

#line 25 "bsemidinotifier.proc"


/* --- current-time --- */
static void
current_time_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 27 "bsemidinotifier.proc"
 {
#line 29 "bsemidinotifier.proc"
  *(in_pspecs++) = bse_param_spec_object ("midi_notifier", "Midi Notifier", NULL,
				 BSE_TYPE_MIDI_NOTIFIER, SFI_PARAM_DEFAULT);
  *(out_pspecs++) = sfi_pspec_int ("msec_time", "Time [ms]", NULL,
			 0, 0, G_MAXINT, 1, SFI_PARAM_DEFAULT);
}
#line 28 "bsemidinotifier.proc"
  proc->help = "Test";
#line 23 "bsemidinotifier.proc"
  proc->authors = "Tim Janik <timj@gtk.org>";
#line 24 "bsemidinotifier.proc"
  proc->copyright = "Copyright (C) 2002 Tim Janik";
#line 34 "bsemidinotifier.proc"
 }
static BseErrorType
#line 34 "bsemidinotifier.proc"
current_time_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 37 "bsemidinotifier.proc"
{
#line 38 "bsemidinotifier.proc"
  
  BseMidiNotifier *self = bse_value_get_object (in_values++);
  struct timeval tv;
  guint64 stamp;
  
#line 43 "bsemidinotifier.proc"
  
  if (!BSE_IS_MIDI_NOTIFIER (self))
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  gettimeofday (&tv, NULL);
  stamp = tv.tv_sec;
  stamp = stamp * 1000000 + tv.tv_usec;
  
#line 51 "bsemidinotifier.proc"
  
  sfi_value_set_int (out_values++, stamp / 1000);
  
  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
static BseExportNodeProc __enode_current_time = {
  { NULL, BSE_EXPORT_NODE_PROC,
    "BseMidiNotifier+current-time", "/Methods/BseMidiNotifier/General/Current Time", NULL },
  0, current_time_setup, current_time_exec, 
};
BseExportNode* bse__builtin_init_bsemidinotifier_gen_proc_c (void);
BseExportNode* bse__builtin_init_bsemidinotifier_gen_proc_c (void)
{
  return (BseExportNode*) &__enode_current_time;
}

/**
 ** Generated data ends here
 **/

==> beast_0.6.1.orig.tar.gz: beast-0.6.1/bse/bsemidinotifier.gen-proc.c <==

/**
 ** Generated data (by mkcproc.pl)
 **/
#line 1 "bsemidinotifier.proc"

#include <bse/bseplugin.h>
#include <bse/bseprocedure.h>
#include <bse/bsemidinotifier.h>
#include <sys/time.h>

#line 25 "bsemidinotifier.proc"


/* --- current-time --- */
static void
current_time_setup (BseProcedureClass *proc, GParamSpec **in_pspecs, GParamSpec **out_pspecs) {
#line 27 "bsemidinotifier.proc"
 {
#line 29 "bsemidinotifier.proc"
  *(in_pspecs++) = bse_param_spec_object ("midi_notifier", "Midi Notifier", NULL,
				 BSE_TYPE_MIDI_NOTIFIER, SFI_PARAM_STANDARD);
  *(out_pspecs++) = sfi_pspec_int ("msec_time", "Time [ms]", NULL,
			 0, 0, G_MAXINT, 1, SFI_PARAM_STANDARD);
}
#line 34 "bsemidinotifier.proc"
 }
static BseErrorType
#line 34 "bsemidinotifier.proc"
current_time_exec (BseProcedureClass *proc,
      const GValue      *in_values,
      GValue            *out_values)
#line 37 "bsemidinotifier.proc"
{
#line 38 "bsemidinotifier.proc"
  
  BseMidiNotifier *self = bse_value_get_object (in_values++);
  struct timeval tv;
  guint64 stamp;
  
#line 43 "bsemidinotifier.proc"
  
  if (!BSE_IS_MIDI_NOTIFIER (self))
    return BSE_ERROR_PROC_PARAM_INVAL;
  
  gettimeofday (&tv, NULL);
  stamp = tv.tv_sec;
  stamp = stamp * 1000000 + tv.tv_usec;
  
#line 51 "bsemidinotifier.proc"
  
  sfi_value_set_int (out_values++, stamp / 1000);
  
  return BSE_ERROR_NONE;
}

/* --- Export to BSE --- */
static BseExportNodeProc __enode_current_time = {
  { NULL, BSE_EXPORT_NODE_PROC,
    "BseMidiNotifier+current-time", 
    NULL,
    "/Methods/BseMidiNotifier/General/Current Time",
    "Test",
    "Tim Janik <timj@gtk.org>",
    "GNU General Public License",
  },
  0, current_time_setup, current_time_exec, 
};
BseExportNode* bse__builtin_init_bsemidinotifier_gen_proc_c (void);
BseExportNode* bse__builtin_init_bsemidinotifier_gen_proc_c (void)
{
  return (BseExportNode*) &__enode_current_time;
}

/**
 ** Generated data ends here
 **/
